@@ -46,7 +46,7 @@ static integer c__3 = 3;
 	    "LFGBG   " "L2TO3   " "VXMIN3  " "VXMAX3  " "VYMIN3  " "VYMAX3  " 
 	    "VZMIN3  " "VZMAX3  " "UXMIN3  " "UXMAX3  " "UYMIN3  " "UYMAX3  " 
 	    "UZMIN3  " "UZMAX3  " "VXORG3  " "VYORG3  " "VZORG3  " "SIMFAC3 " 
-	    "LXLOG3  " "LYLOG3  " "LZLOG3  " "MARKFONT";
+	    "LXLOG3  " "LYLOG3  " "LZLOG3  " "LMRKFNT ";
     static integer itype[122] = { 3,3,2,2,2,2,2,2,1,3,1,1,2,3,3,1,1,1,2,3,1,3,
 	    3,1,1,2,2,1,3,3,3,1,2,1,3,2,3,2,2,3,3,3,3,2,2,1,0,1,1,3,3,3,3,3,3,
 	    3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,1,1,1,3,1,2,2,3,3,3,2,1,3,
