@@ -1,9 +1,16 @@
-/* uxpnum.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -12,7 +19,7 @@ static integer c__12 = 12;
 /* ----------------------------------------------------------------------- */
 /*     UXPNUM : PLOT NUMBERS */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int uxpnum_(char *cside, integer *islct, real *ux, integer *
 	n, ftnlen cside_len)
@@ -22,9 +29,10 @@ static integer c__12 = 12;
 
     /* Local variables */
     static integer i__;
+    static char ch[12*40];
     extern /* Subroutine */ int chval_(char *, real *, char *, ftnlen, ftnlen)
 	    ;
-    static char cfmtz[16], ch[12*40];
+    static char cfmtz[16];
     extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
 	    ftnlen, ftnlen);
     extern logical luxchk_(char *, ftnlen);
